==> healthrian_ble_interface-1.31.0.tar.gz: example/lib/counter/view/counter_page.dart <==
import 'package:example/counter/counter.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';

class CounterPage extends StatelessWidget {
  const CounterPage({super.key});

  @override
  Widget build(BuildContext context) {
    return const CounterView();
  }
}

class CounterView extends StatefulWidget {
  const CounterView({super.key});

  @override
  State<CounterView> createState() => _CounterViewState();
}

class _CounterViewState extends State<CounterView> {
  final _manager = BLEManager();
  late final _module = _manager.module;

  Widget streamWidget(Stream<dynamic>? stream) {
    return StreamBuilder(
      stream: stream,
      builder: (context, snapshot) {
        return Text(snapshot.data.toString());
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Column(
        children: [
          Observer(
            builder: (_) => streamWidget(_module.ble.streams.ble.connection),
          ),
          Observer(
            builder: (_) => streamWidget(_module.ble.streams.ble.battery),
          ),
          Observer(
            builder: (_) => streamWidget(_module.ble.streams.ble.tap),
          ),
          Observer(
            builder: (_) => streamWidget(_module.ble.streams.ecg.preload.raw),
          ),
          Observer(
            builder: (_) =>
                streamWidget(_module.ble.streams.ecg.preload.leadState),
          ),
          Observer(
            builder: (_) =>
                streamWidget(_module.ble.streams.ecg.preload.heartRate),
          ),
        ],
      ),
      floatingActionButton: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          FloatingActionButton(
            onPressed: _manager.connectAndRegister,
          ),
          FloatingActionButton(
            onPressed: _manager.startMeasurement,
          ),
          FloatingActionButton(
            onPressed: _manager.stopMeasurement,
          ),
          FloatingActionButton(
            onPressed: _manager.disconnectDevice,
          ),
        ],
      ),
    );
  }
}

==> healthrian_ble_interface-1.31.6.tar.gz: example/lib/counter/view/counter_page.dart <==
import 'package:example/counter/counter.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';

class CounterPage extends StatelessWidget {
  const CounterPage({super.key});

  @override
  Widget build(BuildContext context) {
    return const CounterView();
  }
}

class CounterView extends StatefulWidget {
  const CounterView({super.key});

  @override
  State<CounterView> createState() => _CounterViewState();
}

class _CounterViewState extends State<CounterView> {
  final _manager = BLEManager();
  late final _module = _manager.module;

  Widget streamWidget(Stream<dynamic>? stream) {
    return StreamBuilder(
      stream: stream,
      builder: (context, snapshot) {
        return Text(snapshot.data.toString());
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Column(
        children: [
          Observer(
            builder: (_) => streamWidget(_module.ble.streams.ble.connection),
          ),
          Observer(
            builder: (_) => streamWidget(_module.ble.streams.ble.battery),
          ),
          Observer(
            builder: (_) => streamWidget(_module.ble.streams.ble.tap),
          ),
          Observer(
            builder: (_) => streamWidget(_module.ble.streams.ecg.preload.raw),
          ),
          Observer(
            builder: (_) =>
                streamWidget(_module.ble.streams.ecg.preload.leadState),
          ),
          Observer(
            builder: (_) =>
                streamWidget(_module.ble.streams.ecg.preload.heartRate),
          ),
        ],
      ),
      floatingActionButton: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          FloatingActionButton(onPressed: _manager.connectAndRegister),
          FloatingActionButton(onPressed: _manager.startMeasurement),
          FloatingActionButton(onPressed: _manager.stopMeasurement),
          FloatingActionButton(onPressed: _manager.disconnectDevice),
        ],
      ),
    );
  }
}
